@@ -57,13 +57,6 @@ val exec :
   (unit -> unit) ->			(* main function *)
   unit
 
-(* Configure a stack.  Supports normal/groupd/protos stacks.
- *)
-val config :
-  Appl_intf.Old.t ->			(* application *)
-  View.full ->				(* view state *)
-  unit
-
 (* Configure a stack.  Supports normal/groupd/protos stacks.
  *)
 val config_new :
@@ -87,7 +80,7 @@ val async :
 (**************************************************************)
 
 val main_loop_opt : unit -> unit
-val init_groupd : unit -> Elink.manage_t (* for perf tests *)
+val init_groupd : unit -> Manage.t2 (* for perf tests *)
 
 (* This starts a "thread" that can be used to monitor
  * various resources in the system.  It should only be
@@ -97,13 +90,6 @@ val start_monitor : unit -> unit
 
 (**************************************************************)
 
-(* Do whatever is necessary to create and initialize a UDP
- * socket.
- *)
-val udp_socket : unit -> Hsys.socket
-
-(**************************************************************)
-
 open Trans
 
 type cast_info = {
@@ -117,6 +103,3 @@ type cast_info = {
 val cast_info : cast_info
 
 (**************************************************************)
-val mpi_info : View.full option ref
-val install_port : Trans.port -> unit
-(**************************************************************)
