@@ -16,11 +16,30 @@
 #define __CE_H__
 
 #include "e_iovec.h"
+#include <memory.h>
 
 #ifdef _WIN32
 #include <winsock2.h>
 #endif
 
+/******************************************************************/
+/* This is for defining DLLs on windows. Do NOT define CE_DLL_LINK
+ * in applications that use the CE library.
+ */
+#ifdef _WIN32
+#ifdef CE_MAKE_A_DLL
+#define LINKDLL __declspec( dllexport)
+#else
+#define LINKDLL __declspec( dllimport)
+#endif
+#else
+/* This is unused on Unix
+ */
+#define LINKDLL 
+#endif
+/******************************************************************/
+
+
 /*! The type of floats used here. Should be the same as an
  * ML float.
  */
@@ -72,6 +91,10 @@ typedef char       *ce_data_t;
  */
 typedef ce_iovec_t *ce_iovec_array_t;
 
+/* An array of boolean values. 
+ */
+typedef ce_bool_t  *ce_bool_array_t;
+
 /*! Arrays of endpoints, these are null terminated arrays of pointers to
  * ce_endpt_t.
  */
@@ -108,23 +131,23 @@ typedef ce_view_id_t **ce_view_id_array_t;
  * The view_state describes the current state of the group, it
  * includes the Ensemble version number, the group name, the rank of the
  * coordinator, and more.
-*/
+ */
 typedef struct ce_view_state_t {
-  char* version ;                /*!< The Ensemble version number */
-  char* group ;                  /*!< The group name */
-  ce_rank_t coord ;              /*!< The rank of the coordinator */
-  int ltime ;                    /*!< The logical time of this view */
-  ce_bool_t primary ;            /*!< Is this a primary view? */
-  char* proto ;                  /*!< The protocol stack in use */
-  ce_bool_t groupd ;             /*!<  Are we using the group daemon? */
-  ce_bool_t xfer_view ;          /*!<  Is this an xfer view? */
-  char* key ;                    /*!<  The security key */
-  int num_ids ;                  /*!<  The number of ids in prev_ids */
-  ce_view_id_array_t prev_ids ;  /*!<  The set of previous view_id's */
-  char *params;                  /*!<  The parameters used */
-  ce_time_t uptime ;             /*!<  The time since this group was initiated */
-  ce_endpt_array_t view ;        /*!<  The set of endpoints in the view */
-  ce_addr_array_t address ;      /*!<  The addresses of group members */
+    char* version ;                /*!< The Ensemble version number */
+    char* group ;                  /*!< The group name */
+    char* proto ;                  /*!< The protocol stack in use */
+    ce_rank_t coord ;              /*!< The rank of the coordinator */
+    int ltime ;                    /*!< The logical time of this view */
+    ce_bool_t primary ;            /*!< Is this a primary view? */
+    ce_bool_t groupd ;             /*!<  Are we using the group daemon? */
+    ce_bool_t xfer_view ;          /*!<  Is this an xfer view? */
+    char* key ;                    /*!<  The security key */
+    int num_ids ;                  /*!<  The number of ids in prev_ids */
+    ce_view_id_array_t prev_ids ;  /*!<  The set of previous view_id's */
+    char *params;                  /*!<  The parameters used */
+    ce_time_t uptime ;             /*!<  The time since this group was initiated */
+    ce_endpt_array_t view ;        /*!<  The set of endpoints in the view */
+    ce_addr_array_t address ;      /*!<  The addresses of group members */
 } ce_view_state_t ;
 
 /*! 
@@ -132,13 +155,13 @@ typedef struct ce_view_state_t {
  * member. 
  */
 typedef struct ce_local_state_t {
-  ce_endpt_t endpt ;             /*!< My endpoint name */
-  ce_addr_t addr ;               /*!< My address */
-  ce_rank_t rank ;               /*!< My rank in the group */
-  char* name ;                   /*!< My name */
-  int nmembers ;                 /*!< The number of members in the view */
-  ce_view_id_t *view_id ;        /*!< The current view_id */
-  ce_bool_t am_coord ;           /*!< Am I the coordinator? */
+    ce_endpt_t endpt ;             /*!< My endpoint name */
+    ce_addr_t addr ;               /*!< My address */
+    ce_rank_t rank ;               /*!< My rank in the group */
+    char* name ;                   /*!< My name */
+    int nmembers ;                 /*!< The number of members in the view */
+    ce_view_id_t *view_id ;        /*!< The current view_id */
+    ce_bool_t am_coord ;           /*!< Am I the coordinator? */
 } ce_local_state_t ;
 
 /*! 
@@ -146,20 +169,20 @@ typedef struct ce_local_state_t {
  * wishes from a created endpoint. 
  */
 typedef struct ce_jops_t {
-  ce_time_t hrtbt_rate ;         /*!< The heartbeat rate */
-  char *transports ;             /*!< The transport protocols [UDP,TCP,MCAST] */
-  char *protocol ;               /*!< The protocol stack to use */
-  char *group_name ;             /*!< The group name */
-  char *properties ;             /*!< The set of properties */
-  ce_bool_t use_properties ;     /*!< Use the properties, instead of the protocol ? */
-  ce_bool_t groupd ;             /*!< Use the group daemon? */
-  char *params ;                 /*!< The set of parameters */
-  ce_bool_t debug ;              /*!< Use the debugging version */
-  ce_bool_t client;              /*!< Are we a Client? */
-  char *endpt ;                  /*!< the requested endpoint name */
-  char *princ ;                  /*!< My principal name (security) */
-  char *key ;                    /*!< The security key */
-  ce_bool_t secure ;             /*!< Do we want a secure stack (encryption + authentication? */
+    ce_time_t hrtbt_rate ;         /*!< The heartbeat rate */
+    char *transports ;             /*!< The transport protocols [UDP,TCP,MCAST] */
+    char *protocol ;               /*!< The protocol stack to use */
+    char *group_name ;             /*!< The group name */
+    char *properties ;             /*!< The set of properties */
+    ce_bool_t use_properties ;     /*!< Use the properties, instead of the protocol ? */
+    ce_bool_t groupd ;             /*!< Use the group daemon? */
+    char *params ;                 /*!< The set of parameters */
+    ce_bool_t client;              /*!< Are we a Client? */
+    ce_bool_t debug ;              /*!< Use the debugging version */
+    char *endpt ;                  /*!< the requested endpoint name */
+    char *princ ;                  /*!< My principal name (security) */
+    char *key ;                    /*!< The security key */
+    ce_bool_t secure ;             /*!< Do we want a secure stack (encryption + authentication? */
 } ce_jops_t;
 
 /*!  
@@ -194,18 +217,18 @@ typedef struct ce_jops_t {
 /*! copy a C string.
  * @param str : a C string (ends with '\0')
  */
-char *ce_copy_string(char *str);
+LINKDLL char *ce_copy_string(char *str);
 
 /*! Free a local-state and a view-state.
  * @param ls  A local-state structure.
  * @param vs  A view-state structure. 
  */
-void ce_view_full_free(ce_local_state_t *ls, ce_view_state_t* vs);
+LINKDLL void ce_view_full_free(ce_local_state_t *ls, ce_view_state_t* vs);
 
 /*! Free a jops structure.
  * @param jops A join-options structure. 
  */
-void ce_jops_free(ce_jops_t*) ;
+LINKDLL void ce_jops_free(ce_jops_t*) ;
 
 /**************************************************************/
 /*! The application interface. An application has to define several callbacks
@@ -213,6 +236,8 @@ void ce_jops_free(ce_jops_t*) ;
  */
 
 /*! Install is called whenever a new view is installed.
+ * Fresh local and view_states are handed to the application, they 
+ * are hence owned by the application. 
  */
 typedef void (*ce_appl_install_t)(ce_env_t, ce_local_state_t*, ce_view_state_t*);
 
@@ -280,7 +305,7 @@ typedef struct ce_appl_intf_t ce_appl_intf_t ;
  *                   Consumed.
  *                   
  */
-ce_appl_intf_t*
+LINKDLL ce_appl_intf_t*
 ce_create_intf(ce_env_t env, 
 	       ce_appl_exit_t exit,
 	       ce_appl_install_t install,
@@ -289,31 +314,37 @@ ce_create_intf(ce_env_t env,
 	       ce_appl_receive_cast_t cast,
 	       ce_appl_receive_send_t send,
 	       ce_appl_heartbeat_t heartbeat
-	       );
+    );
 
 /**************************************************************/
 
 /*! Initialize the Ensemble data structures, and process the
- * command line arguemnts.
+ * command line arguments.
+ *
+ * The command line arguments are:
+ *  1) Those accepted by Ensemble
+ *  2) -outboard <mode>  In case we're using outboard, which, mode to use:
+ *      a) FORK: Unix, fork an Ensemble process
+ *      b) SPAWN: WIN32, spawn an Ensemble process
+ *      c) TCP: connect to an existing Ensemble daemon through TCP.
  */
-void ce_Init(
-        int argc,
-        char **argv
-) ;
+LINKDLL void ce_Init(
+    int argc,
+    char **argv
+    ) ;
 
 /*!  Transfer control to Ensemble, and start the main loop.
  */
-void ce_Main_loop (
-);
-			 
+LINKDLL void ce_Main_loop (void);
+
 /*! Join a group. 
  * @param ops  A structure describing the join options for this stack. Consumed.
  * @param c_appl An application-interface created earlier.
  */ 
-void ce_Join(
-        ce_jops_t *ops,
-	ce_appl_intf_t *c_appl
-) ;
+LINKDLL void ce_Join(
+    ce_jops_t *ops,
+    ce_appl_intf_t *c_appl
+    ) ;
 
 /**************************************************************/
 /* The set of actions supported on a group. 
@@ -322,18 +353,18 @@ void ce_Join(
 /*! Leave a group.  After this downcall, the context becomes invalid.
  * @param c_appl The stack that should be closed.
  */
-void ce_Leave(ce_appl_intf_t *c_appl) ;
+LINKDLL void ce_Leave(ce_appl_intf_t *c_appl) ;
 
 /*!  Send a multicast message to the group.
  * @param c_appl The C-interface.
  * @param num The length of the iovec array.
  * @param iovl an array of io-vectors. The iovl array is consumed.
  */
-void ce_Cast(
-	ce_appl_intf_t *c_appl,
-	int num,
-	ce_iovec_array_t iovl
-) ;
+LINKDLL void ce_Cast(
+    ce_appl_intf_t *c_appl,
+    int num,
+    ce_iovec_array_t iovl
+    ) ;
 
 /*!  Send a point-to-point message to a set of group members.
  * @param c_appl The C-interface.
@@ -342,13 +373,13 @@ void ce_Cast(
  * @param num The length of the iovec array.
  * @param iovl an array of io-vectors. The iovl array is consumed.
  */
-void ce_Send(
-	ce_appl_intf_t *c_appl,
-	int num_dests,
-	ce_rank_array_t dests,
-	int num,
-	ce_iovec_array_t iovl
-) ;
+LINKDLL void ce_Send(
+    ce_appl_intf_t *c_appl,
+    int num_dests,
+    ce_rank_array_t dests,
+    int num,
+    ce_iovec_array_t iovl
+    ) ;
 
 
 /*!  Send a point-to-point message to the specified group member.
@@ -357,44 +388,44 @@ void ce_Send(
  * @param num The length of the iovec array.
  * @param iovl an array of io-vectors. The iovl array is consumed.
  */
-void ce_Send1(
-	ce_appl_intf_t *c_appl,
-	ce_rank_t dest,
-	int num,
-	ce_iovec_array_t iovl
-) ;
+LINKDLL void ce_Send1(
+    ce_appl_intf_t *c_appl,
+    ce_rank_t dest,
+    int num,
+    ce_iovec_array_t iovl
+    ) ;
 
 /*!  Ask for a new View.
  * @param c_appl The C-interface.
  */
-void ce_Prompt(
-	ce_appl_intf_t *c_appl
-);
+LINKDLL void ce_Prompt(
+    ce_appl_intf_t *c_appl
+    );
 
 /*!  Report specified group members as failure-suspected.
  * @param c_appl The C-interface.
  * @param num The length of the suspects array
  * @param suspects A list of member ranks. The array is consumed.
  */
-void ce_Suspect(
-	ce_appl_intf_t *c_appl,
-	int num,
-	ce_rank_array_t suspects
-);
-	
+LINKDLL void ce_Suspect(
+    ce_appl_intf_t *c_appl,
+    int num,
+    ce_rank_array_t suspects
+    );
+
 /*!  Inform Ensemble that the state-transfer is complete. 
  * @param c_appl The C-interface.
  */
-void ce_XferDone(
-	ce_appl_intf_t *c_appl
-) ;
+LINKDLL void ce_XferDone(
+    ce_appl_intf_t *c_appl
+    ) ;
 
 /*!  Ask the system to rekey.
  * @param c_appl The C-interface.
  */
-void ce_Rekey(
-	ce_appl_intf_t *c_appl
-) ;
+LINKDLL void ce_Rekey(
+    ce_appl_intf_t *c_appl
+    ) ;
 
 /*!  Request a protocol change.
  * @param c_appl The C-interface.
@@ -406,10 +437,10 @@ void ce_Rekey(
  *     Frag:Pt2ptw:Mflow:Pt2pt:Mnak:Bottom"
  * The protocl_name is consumed.
  */
-void ce_ChangeProtocol(
-        ce_appl_intf_t *c_appl,
-	char *protocol_name
-) ;
+LINKDLL void ce_ChangeProtocol(
+    ce_appl_intf_t *c_appl,
+    char *protocol_name
+    ) ;
 
 
 /*!  Request a protocol change (specify properties).
@@ -418,10 +449,10 @@ void ce_ChangeProtocol(
  *    properties. For example: "Gmp:Sync:Heal:Switch:Frag:Suspect:Flow:Xfer"
  * The properties string is consumed.
  */
-void ce_ChangeProperties(
-        ce_appl_intf_t *c_appl,
-	char *properties
-) ;
+LINKDLL void ce_ChangeProperties(
+    ce_appl_intf_t *c_appl,
+    char *properties
+    ) ;
 
 /**************************************************************/
 /*!  Auxiliary functions.
@@ -430,17 +461,17 @@ void ce_ChangeProperties(
 /*! Allows overriding the default ML value printer.
  * For the power-user.
  */
-void ce_MLPrintOverride(
-	void (*handler)(char *msg)
-) ;
-
+LINKDLL void ce_MLPrintOverride(
+    void (*handler)(char *msg)
+    ) ;
+    
 /*! Allows overriding the default ML exception handler.
  * For the power-user.
  */
-void ce_MLUncaughtException(
-	void (*handler)(char *info)
-) ;
-
+LINKDLL void ce_MLUncaughtException(
+    void (*handler)(char *info)
+    ) ;
+    
 /**************************************************************/
 /*! CE_Socket allows an os-independent representation for
  * sockets.
@@ -462,18 +493,18 @@ typedef void (*ce_handler_t)(void*);
  * @param handler A handler.
  * @param env An envrionment variable. 
  */
-void ce_AddSockRecv(
-		    CE_SOCKET socket,
-		    ce_handler_t handler,
-		    ce_env_t env
-		    );
+LINKDLL void ce_AddSockRecv(
+    CE_SOCKET socket,
+    ce_handler_t handler,
+    ce_env_t env
+    );
 
 /*! Remove a socket from the list Ensemble listens to.
  *@param socket The socket to remove. 
-*/
-void ce_RmvSockRecv(
-		    CE_SOCKET socket
-		    );
+ */
+LINKDLL void ce_RmvSockRecv(
+    CE_SOCKET socket
+    );
 
 /**************************************************************/
 /* Here is a simpler "flat" inteface.
@@ -500,27 +531,28 @@ typedef void (*ce_appl_flat_receive_send_t)(ce_env_t, ce_rank_t, ce_len_t, ce_da
 
 /*! Create an application interface using flat callbacks. 
  */
-ce_appl_intf_t*
+LINKDLL ce_appl_intf_t*
 ce_create_flat_intf(ce_env_t env, 
-	       ce_appl_exit_t exit,
-	       ce_appl_install_t install,
-	       ce_appl_flow_block_t flow_block,
-	       ce_appl_block_t block,
-	       ce_appl_flat_receive_cast_t cast,
-	       ce_appl_flat_receive_send_t send,
-	       ce_appl_heartbeat_t heartbeat
-	       );
+		    ce_appl_exit_t exit,
+		    ce_appl_install_t install,
+		    ce_appl_flow_block_t flow_block,
+		    ce_appl_block_t block,
+		    ce_appl_flat_receive_cast_t cast,
+		    ce_appl_flat_receive_send_t send,
+		    ce_appl_heartbeat_t heartbeat
+    );
 
 
 /*!  Send a multicast message to the group.
  * @param c_appl The C-interface.
  * @param len The length of the message.
  * @param buf The data to send. The buffer is consumed.
- */void ce_flat_Cast(
-	ce_appl_intf_t *c_appl,
-	ce_len_t len, 
-	ce_data_t buf
-) ;
+ */
+LINKDLL void ce_flat_Cast(
+     ce_appl_intf_t *c_appl,
+     ce_len_t len, 
+     ce_data_t buf
+     ) ;
 
 /*!  Send a point-to-point message to a set of group members.
  * @param c_appl The C-inteface.
@@ -529,13 +561,13 @@ ce_create_flat_intf(ce_env_t env,
  * @param len The length of the message.
  * @param buf The data to send. The buffer is consumed.
  */
-void ce_flat_Send(
-	ce_appl_intf_t *c_appl,
-	int num_dests,
-	ce_rank_array_t dests,
-	ce_len_t len, 
-	ce_data_t buf
-) ;
+LINKDLL void ce_flat_Send(
+    ce_appl_intf_t *c_appl,
+    int num_dests,
+    ce_rank_array_t dests,
+    ce_len_t len, 
+    ce_data_t buf
+    ) ;
 
 
 /*!  Send a point-to-point message to the specified group member.
@@ -544,12 +576,12 @@ void ce_flat_Send(
  * @param len The length of the message.
  * @param buf The data to send. The buffer is consumed.
  */
-void ce_flat_Send1(
-	ce_appl_intf_t *c_appl,
-	ce_rank_t dest,
-	ce_len_t len, 
-	ce_data_t buf
-) ;
+LINKDLL void ce_flat_Send1(
+    ce_appl_intf_t *c_appl,
+    ce_rank_t dest,
+    ce_len_t len, 
+    ce_data_t buf
+    ) ;
 
 #endif  /* __CE_H__ */
 
