@@ -6,8 +6,7 @@
 /* Caml already contains the implementation of these
  * functions. 
  */
-
-typedef unsigned long uint32 ;
+#include "caml/config.h"
 
 struct MD5Context {
     uint32 buf[4];
@@ -16,7 +15,7 @@ struct MD5Context {
 };
 
 void MD5Init(struct MD5Context *ctx);
-void MD5Update(struct MD5Context *ctx, unsigned char *buf, unsigned int len);
+void MD5Update(struct MD5Context *ctx, const unsigned char *buf, unsigned int len);
 void MD5Final(unsigned char *digest, struct MD5Context *ctx);
 
 #endif /* __CE_MD5_H__ */
