@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* DISP.ML *)
 (* Author: Mark Hayden, 6/95 *)
 (* Based on code by Werner Vogels *)
@@ -35,6 +26,6 @@ let l _ (ls,vs) = ((),fun {up_lout=up;dn_lout=dn} ->
     dn ev hdr
   in {up_lin=up_hdlr;dn_lin=dn_hdlr})
 
-let _ = Elink.layer_install "DISP" l
+let _ = Layer.install "DISP" l
 
 (**************************************************************)
