@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* PARTIAL_APPL.ML *)
 (* Author: Mark Hayden, 8/95 *)
 (* Modified: Xiaoming Liu with Robbert vanRenesse 2/98 *)
@@ -265,6 +256,6 @@ in {up_in=up_hdlr;uplm_in=uplm_hdlr;upnm_in=upnm_hdlr;dn_in=dn_hdlr;dnnm_in=dnnm
 
 let l args vs = Layer.hdr init hdlrs None (LocalNoHdr ()) args vs
 
-let _ = Elink.layer_install name l
+let _ = Layer.install name l
 
 (**************************************************************)
