@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* SECCHAN: Creating secure channels between ensemble processes.*)
 (* Author: Ohad Rodeh  2/98 *)
 (**************************************************************)
@@ -178,7 +169,7 @@ let hdlrs s ((ls,vs) as vf) {up_out=up;upnm_out=upnm;dn_out=dn;dnlm_out=dnlm;dnn
       let key = compute_key bignum in
       match ch.status with 
 	| SemiOpen -> 
-	    ch.key <- Some (Security.cipher_of_buf (Buf.of_string name key));
+	    ch.key <- Some (Security.cipher_of_buf (Buf.of_string key));
 	    ch.status <- Open;
 	    Queue.iter (fun (msg,abv) -> 
 	      let msg  = encrypt ch.key msg in
@@ -194,7 +185,7 @@ let hdlrs s ((ls,vs) as vf) {up_out=up;upnm_out=upnm;dn_out=dn;dnlm_out=dnlm;dnn
 
 	let key = compute_key bignum in
 	let ch = {
-	  key   = Some (Security.cipher_of_buf (Buf.of_string name key));
+	  key   = Some (Security.cipher_of_buf (Buf.of_string key));
 	  msgs  = Queue.create ();
 	  status = Open
 	} in
@@ -368,7 +359,7 @@ let l args vf = Layer.hdr init hdlrs None NoOpt args vf
 let _ = 
   Param.default "secchan_debug" (Param.Bool false);
   Param.default "secchan_key_len" (Param.Int 768);
-  Elink.layer_install name l
+  Layer.install name l
     
 (**************************************************************)
     
