@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* UNIQUE.MLI *)
 (* Author: Mark Hayden, 8/96 *)
 (**************************************************************)
@@ -23,7 +14,7 @@ type id
 
 (* Constructors.
  *)
-val create : inet -> incarn -> t
+val create : Hsys.inet -> incarn -> t
 val id : t -> id
 
 (* Display functions.
